what.models.detection.frcnn API documentation

# what.models.detection.frcnn

This module implements Faster-RCNN object detection model.

## what.models.detection.frcnn.faster_rcnn

View Source

     1r'''
     2This module implements Faster-RCNN object detection model.
     3
     4<br />
     5
     6## what.models.detection.frcnn.faster_rcnn
     7
     8'''
     9
    10from what.models.detection.frcnn.faster_rcnn import FasterRCNN
    11
    12__all__ = ["faster_rcnn"]